import { CompilationContext } from './CompilationContext';
import type * as C from '../dist/json-schema/sessionCapture.schema';
/** Class implementing the session compilation process. */
export declare class SessionCompiler {
    private readonly context;
    private readonly chunks;
    private readonly loms;
    private readonly timeline;
    private readonly navigationTimings;
    private readonly resourceTimings;
    private readonly session;
    private chunksGeneral;
    private currentChunk;
    private previousFaultyTs;
    private lomDeduplicationMapping;
    private lomCounter;
    private constructor();
    static create(context: CompilationContext): Promise<string[]>;
    /**
     * Fragmentation of sessions based on their period of inactivity
     *
     * @param context Compilation context
     * @param chunks Chunks of the session obtained by to the context
     * @param sessionId The session identifier
     * @param userId The user identifier
     *
     * @returns List of generated identifiers corresponding to each fragmented session
     */
    private static sessionFragmentation;
    /**
     * Get the active chunks of a session
     *
     * @param context Compilation context
     * @param chunks Chunks of the session obtained by to the context
     * @param chunk The current active chunk
     * @param session List of active chunks of the session
     * @param limitSession Estimated inactivity time limit
     * @param index Current iteration index
     * @param sessionsId List of generated identifiers corresponding to each fragmented session
     * @param parentId The source session identifier
     * @param currentId The current session identifier
     * @param isInactive Session activity flag
     * @param userId The user identifier
     *
     * @returns Updated session informatio
     */
    static getActiveChunks(context: CompilationContext, chunks: C.SessionCapture[], chunk: C.SessionCapture, session: C.SessionCapture[], limitSession: number, index: number, sessionsId: string[], parentId: string, currentId: string, isInactive: boolean, userId?: string): Promise<{
        session: C.SessionCapture[];
        sessionsId: string[];
        isInactive: boolean;
        currentId: string;
    }>;
    /**
     * Get the inactive chunks of a session
     *
     * @param context Compilation context
     * @param chunk The current inactive chunk
     * @param session List of inactive chunks of the session
     * @param limitSessionInactive Estimated time limit to restart the activity
     * @param sessionsId List of generated identifiers corresponding to each fragmented session
     * @param parentId The source session identifier
     * @param currentId The source session identifier
     * @param nextId The new session identifier to be started
     * @param isInactive Session activity flag
     * @param userId The user identifier
     *
     * @returns Updated session information
     */
    static getInactiveChunks(context: CompilationContext, chunks: C.SessionCapture[], chunk: C.SessionCapture, session: C.SessionCapture[], limitSessionInactive: number, sessionsId: string[], parentId: string, currentId: string, nextId: string, isInactive: boolean, userId?: string): Promise<{
        inactiveSession: C.SessionCapture[];
        activeSession: C.SessionCapture[];
        sessionsId: string[];
        isInactive: boolean;
        currentId: string;
        nextId: string;
    }>;
    static minElapsed(previousTimestamp?: number | undefined, currentTimestamp?: number | undefined): number;
    private relativizeTimestampToSession;
    private addToTimeline;
    private addNavigationTiming;
    private addResourceTiming;
    private createExplorationEvent;
    private createActionEvent;
    private findSimilarLom;
    compile(sessionId: string): Promise<void>;
}
